Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(178)

Unified Diff: src/builtins/x87/builtins-x87.cc

Issue 2448933002: [compiler] Make SFI "optimize" flag a "tier up" flag (Closed)
Patch Set: Do some renaming and remove a DCHECK Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/builtins/x64/builtins-x64.cc ('k') | src/compiler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/builtins/x87/builtins-x87.cc
diff --git a/src/builtins/x87/builtins-x87.cc b/src/builtins/x87/builtins-x87.cc
index 237a8ee1954670887350d937b212a9375148425d..38c20e32e40ab9f398331cecb944f578db876d30 100644
--- a/src/builtins/x87/builtins-x87.cc
+++ b/src/builtins/x87/builtins-x87.cc
@@ -1162,12 +1162,9 @@ void Builtins::Generate_CompileLazy(MacroAssembler* masm) {
__ pop(new_target);
__ pop(argument_count);
__ mov(entry, FieldOperand(closure, JSFunction::kSharedFunctionInfoOffset));
- // Is the shared function marked for optimization?
- __ test_b(
- FieldOperand(entry,
- SharedFunctionInfo::kWasMarkedForOptimizationByteOffset),
- Immediate(
- 1 << SharedFunctionInfo::kWasMarkedForOptimizationBitWithinByte));
+ // Is the shared function marked for tier up?
+ __ test_b(FieldOperand(entry, SharedFunctionInfo::kMarkedForTierUpByteOffset),
+ Immediate(1 << SharedFunctionInfo::kMarkedForTierUpBitWithinByte));
__ j(not_zero, &gotta_call_runtime_no_stack);
// Is the full code valid?
__ mov(entry, FieldOperand(entry, SharedFunctionInfo::kCodeOffset));
« no previous file with comments | « src/builtins/x64/builtins-x64.cc ('k') | src/compiler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698